summaryrefslogtreecommitdiffstats
path: root/src/H5HFhdr.c
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@lbl.gov>2020-08-06 22:46:40 (GMT)
committerQuincey Koziol <koziol@lbl.gov>2020-08-06 22:46:40 (GMT)
commit8fe3cece3c671453e4c49f22fde9d7635c08f031 (patch)
tree6dd0d609a234b413530ce696e6cff9b669cdcce4 /src/H5HFhdr.c
parent07e4ef9da47eda1f23ca72c748fbb6d4b309540b (diff)
downloadhdf5-8fe3cece3c671453e4c49f22fde9d7635c08f031.zip
hdf5-8fe3cece3c671453e4c49f22fde9d7635c08f031.tar.gz
hdf5-8fe3cece3c671453e4c49f22fde9d7635c08f031.tar.bz2
Switch H5VM inline routines back to single underscope and put a comment in their header about this naming
Diffstat (limited to 'src/H5HFhdr.c')
-rw-r--r--src/H5HFhdr.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/H5HFhdr.c b/src/H5HFhdr.c
index 4a645cd..043ab87 100644
--- a/src/H5HFhdr.c
+++ b/src/H5HFhdr.c
@@ -46,7 +46,7 @@
#ifndef NDEBUG
/* Limit on the size of the max. direct block size */
/* (This is limited to 32-bits currently, because I think it's unlikely to
* need to be larger, the 32-bit limit for H5VM__log2_of2(n), and
* some offsets/sizes are encoded with a maximum of 32-bits - QAK)
*/
#define H5HF_MAX_DIRECT_SIZE_LIMIT ((hsize_t)2 * 1024 * 1024 * 1024)
@@ -221,7 +221,7 @@ H5HF__hdr_finish_init_phase1(H5HF_hdr_t *hdr)
/* Set the size of heap IDs */
hdr->heap_len_size = (uint8_t)MIN(hdr->man_dtable.max_dir_blk_off_size,
- H5VM__limit_enc_size((uint64_t)hdr->max_man_size));
+ H5VM_limit_enc_size((uint64_t)hdr->max_man_size));
done:
FUNC_LEAVE_NOAPI(ret_value)
@@ -1070,7 +1070,7 @@ H5HF__hdr_update_iter(H5HF_hdr_t *hdr, size_t min_dblock_size)
unsigned child_entry; /* Entry of child indirect block */
/* Compute # of rows needed in child indirect block */
- child_rows_needed = (H5VM__log2_of2((uint32_t)min_dblock_size) - H5VM__log2_of2((uint32_t)hdr->man_dtable.cparam.start_block_size)) + 2;
+ child_rows_needed = (H5VM_log2_of2((uint32_t)min_dblock_size) - H5VM_log2_of2((uint32_t)hdr->man_dtable.cparam.start_block_size)) + 2;
HDassert(child_rows_needed > child_nrows);
child_entry = (next_row + (child_rows_needed - child_nrows)) * hdr->man_dtable.cparam.width;
if(child_entry > (iblock->nrows * hdr->man_dtable.cparam.width))
@@ -46,7 +46,7 @@
/* Limit on the size of the max. direct block size */
/* (This is limited to 32-bits currently, because I think it's unlikely to
- * need to be larger, the 32-bit limit for H5VM__log2_of2(n), and
+ * need to be larger, the 32-bit limit for H5VM_log2_of2(n), and
* some offsets/sizes are encoded with a maximum of 32-bits - QAK)
*/